pub enum Popup {
IsOpen(Property),
Direction(PopupDirection),
Size(u32, u32),
Offset(u32),
}Expand description
Attributes associated with controlling a popup
Variants
IsOpen(Property)
Whether or not this popup is open (popups are closed by default)
Direction(PopupDirection)
The direction in which this popup should appear relative to its parent control
Size(u32, u32)
The size in pixels of this popup
Offset(u32)
The offset in pixels for the popup along the direction it’s opening in