UiSessionState

Struct UiSessionState 

pub struct UiSessionState { /* private fields */ }
Represents the most recent state of a UI session

Implementations

Source

impl UiSessionState

pub fn new() -> UiSessionState

Creates a new UI session state (which initially stores no state)

pub fn update_ui(&mut self, new_ui: &Control) -> Option<UiUpdate>

Updates the UI for this element, returning the corresponding update event

pub fn watch_viewmodel(&mut self, controller: Arc<dyn Controller>)

Starts watching the viewmodel for a controller

pub fn get_viewmodel_update(&mut self) -> Option<UiUpdate>

Retrieves the viewmodel update event, if there is one

pub fn watch_canvases(&mut self, ui_binding: &BindRef<Control>)

Watches for updates to canvases in the specified UI

pub fn get_canvas_update(&mut self) -> Option<UiUpdate>

Retrieves the updates to any canvases attached to this object

pub fn get_updates(&mut self, ui_binding: &BindRef<Control>) -> Vec<UiUpdate>

Retrieves the updates that are pending in this object