pub struct UiSessionState { /* private fields */ }Expand description
Represents the most recent state of a UI session
Implementations
Sourceimpl UiSessionState
impl UiSessionState
Sourcepub fn new() -> UiSessionState
pub fn new() -> UiSessionState
Creates a new UI session state (which initially stores no state)
Sourcepub fn update_ui(&mut self, new_ui: &Control) -> Option<UiUpdate>
pub fn update_ui(&mut self, new_ui: &Control) -> Option<UiUpdate>
Updates the UI for this element, returning the corresponding update event
Sourcepub fn watch_viewmodel(&mut self, controller: Arc<dyn Controller>)
pub fn watch_viewmodel(&mut self, controller: Arc<dyn Controller>)
Starts watching the viewmodel for a controller
Sourcepub fn get_viewmodel_update(&mut self) -> Option<UiUpdate>
pub fn get_viewmodel_update(&mut self) -> Option<UiUpdate>
Retrieves the viewmodel update event, if there is one
Sourcepub fn watch_canvases(&mut self, ui_binding: &BindRef<Control>)
pub fn watch_canvases(&mut self, ui_binding: &BindRef<Control>)
Watches for updates to canvases in the specified UI
Sourcepub fn get_canvas_update(&mut self) -> Option<UiUpdate>
pub fn get_canvas_update(&mut self) -> Option<UiUpdate>
Retrieves the updates to any canvases attached to this object